==> vradi-swing-0.0.1-sources.jar: com/jurismarches/vradi/ui/editors/StringEditor.java <==
package com.jurismarches.vradi.ui.editors;

import com.jurismarches.vradi.ui.editors.*;
import java.awt.*;
import java.awt.event.*;
import java.beans.*;
import java.io.*;
import java.lang.*;
import java.util.*;
import javax.swing.*;
import javax.swing.border.*;
import javax.swing.event.*;
import jaxx.runtime.swing.JAXXButtonGroup;
import jaxx.runtime.swing.HBox;
import jaxx.runtime.swing.VBox;
import jaxx.runtime.swing.Table;
import jaxx.runtime.Util;
import jaxx.runtime.SwingUtil;
import static org.nuiton.i18n.I18n._;
import static jaxx.runtime.Util.createImageIcon;
import com.jurismarches.vradi.entities.*;
import com.jurismarches.vradi.services.dto.*;
import com.jurismarches.vradi.VradiContext;
import jaxx.runtime.swing.editor.*;
import jaxx.runtime.swing.EntityComboBox;
import static jaxx.runtime.validator.BeanValidatorUtil.convert;
import static jaxx.runtime.SwingUtil.getStringValue;
import static org.nuiton.i18n.I18n.n_;
import com.jurismarches.vradi.ui.OfferEditHandler;
import org.jdesktop.swingx.JXDatePicker;
import jaxx.runtime.DataBindingListener;

public class StringEditor extends com.jurismarches.vradi.ui.editors.VradiEditor {
    private static String $jaxxObjectDescriptor = "H4sIAAAAAAAAAI1SsW4TQRR8PmwHJzFJsLCCCFKA1GuojSDIYEFkQMIRinDD2ruK1zrfbXbfJUeD+AQ+AXoaJDoqREFNQYP4BYQoaBFv7xyfDYfAxVnaNzM7O/NefYWSNXBhxOOYmShANZZs58be3v3+SA7wprQDozSGBtJfwQOvB0tiem4RLvU6jt6Y0ButcKzDQAYz7GYHFi0+8aUdSokI5+cZA2sb3em4GevIHKtOTeWpvvj+zXsunr30AGJN7or0lM1/sbKXFDvgKYFwmm465A2fB/tkw6hgn/xW3VnL59be42N5AE9hoQNlzQ2JIVz8/ycnGgk/1gjVrYeGC3VLKMJcRmCDcMxGkVF2zM1gKC07dHMWKSYTjGWppZShdSJVRigKjhxh1dlkzvoElyGqqUArDDDxvD6XjD0iMNvlfV9mlOWtnV0ZY1tJX1xBqDvxeALNJg68oinrc3OK1CLLWsxiLvSgZCI6Jgu9P4t/QKO08vXfKneCyfRnvfbp7Zc37eOeC3T3mVzozJpS/tqEWhpU7uqVtOQIld+4y3WzBxUrfdrxZIc3cox1J2MyR/etJUE7OrvN7ZAkSguf372vP/54Arw2LPohF23u8HeggkNDKYS+iPX17cTR8tFJ+q46b9QdUpQIp666Djf7KhAU8LWYItjIiWDqo1/58KPWfb09G8PZv8KzKEqPoKwCXwUyWfjJLucu+JK2MhJhtrN5W1xw/zWt9S/N18N1PgQAAA==";
    private static final long serialVersionUID = 1L;
    protected java.lang.String data;
    private javax.swing.JTextField $JTextField1;
    private StringEditor $VradiEditor0 = this;
    private boolean allComponentsCreated;
    private boolean contextInitialized = true;
    private PropertyChangeListener $DataSource2 = new DataBindingListener(this, "$JTextField1.text");

    /* begin raw body code */    
    
    protected OfferEditHandler getHandler() {
        return getContextValue(OfferEditHandler.class);
    }
    
    protected VradiContext getVradiContext() {
        return VradiContext.get();
    }
    
    void $afterCompleteSetup() {
    }
    /* end raw body code */
    /*---------------------------------------------------------------------------------*/
    /*-- Statics methods --------------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public static jaxx.runtime.JAXXObjectDescriptor $getJAXXObjectDescriptor() {
        return jaxx.runtime.Util.decodeCompressedJAXXObjectDescriptor($jaxxObjectDescriptor);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- Constructors -----------------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public StringEditor() {
        super();
        $initialize();
    }

    public StringEditor(jaxx.runtime.JAXXContext parentContext) {
        super(parentContext);
        $initialize();
    }

    /*---------------------------------------------------------------------------------*/
    /*-- JAXXObject implementation ----------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    @Override
    public void applyDataBinding(String $binding) {
        if ("$JTextField1.text".equals($binding)) {    
            addPropertyChangeListener("data", $DataSource2);
        } else {
            super.applyDataBinding($binding);
            return;
        }
        processDataBinding($binding);
    }

    @Override
    public void processDataBinding(String $dest, boolean $force) {
        if (!$force && $activeBindings.contains($dest)) { 
            return;
        }
        $activeBindings.add($dest);
        try {
            if ("$JTextField1.text".equals($dest)) {
                jaxx.runtime.SwingUtil.setText($JTextField1, getData());
            } else {
                super.processDataBinding($dest, true);
            }
        } finally {
            $activeBindings.remove($dest);
        }
    }

    @Override
    public void removeDataBinding(String $binding) {
        if ("$JTextField1.text".equals($binding)) {    
            removePropertyChangeListener("data", $DataSource2);
        } else {
            super.removeDataBinding($binding);
        }
    }

    /*---------------------------------------------------------------------------------*/
    /*-- public acessor methods -------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public java.lang.String getData() {
        return data;
    }

    /*---------------------------------------------------------------------------------*/
    /*-- public mutator methods -------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public void setData(java.lang.String newValue) {
        java.lang.String oldValue = this.data;
        this.data = newValue;
        firePropertyChange("data", oldValue, newValue);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- protected acessors methods ---------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    protected javax.swing.JTextField get$JTextField1() {
        return $JTextField1;
    }

    /*---------------------------------------------------------------------------------*/
    /*-- ui creation methods ----------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    private void $completeSetup() {
        allComponentsCreated = true;
        addChildrenToEditorContent();
        // init data bindings
        applyDataBinding("$JTextField1.text");
        $afterCompleteSetup();
    }

    private void $initialize() {
        if (allComponentsCreated || !contextInitialized) {
            return;
        }
        $objectMap.put("$VradiEditor0", this);
        createData();
        // inline creation of $JTextField1
        $objectMap.put("$JTextField1", $JTextField1 = new javax.swing.JTextField());
        $JTextField1.setName("$JTextField1");
        $JTextField1.setColumns(15);
        // inline creation of $VradiEditor0
        removeDataBinding("$Table0.name");
        setName("$VradiEditor0");
        
        $completeSetup();
    }

    protected void addChildrenToEditorContent() {
        if (!allComponentsCreated) {
            return;
        }
        editorContent.add($JTextField1, new GridBagConstraints(0, 0, 1, 1, 1.0, 0.0, 10, 2, new Insets(0, 0, 0, 0), 0, 0));
    }

    protected void createData() {
        $objectMap.put("data", data = null);
    }

    @Override
    protected void createEditorContent() {
        $objectMap.put("editorContent", editorContent = new jaxx.runtime.swing.Table());
        editorContent.setName("editorContent");
    }

}

==> vradi-swing-0.0.2-sources.jar: com/jurismarches/vradi/ui/editors/StringEditor.java <==
package com.jurismarches.vradi.ui.editors;

import com.jurismarches.vradi.ui.editors.*;
import java.awt.*;
import java.awt.event.*;
import java.beans.*;
import java.io.*;
import java.lang.*;
import java.util.*;
import javax.swing.*;
import javax.swing.border.*;
import javax.swing.event.*;
import jaxx.runtime.swing.JAXXButtonGroup;
import jaxx.runtime.swing.HBox;
import jaxx.runtime.swing.VBox;
import jaxx.runtime.swing.Table;
import jaxx.runtime.Util;
import jaxx.runtime.SwingUtil;
import static org.nuiton.i18n.I18n._;
import static jaxx.runtime.Util.createImageIcon;
import com.jurismarches.vradi.entities.*;
import com.jurismarches.vradi.services.dto.*;
import com.jurismarches.vradi.VradiContext;
import jaxx.runtime.swing.editor.*;
import jaxx.runtime.swing.EntityComboBox;
import static jaxx.runtime.validator.BeanValidatorUtil.convert;
import static jaxx.runtime.SwingUtil.getStringValue;
import static org.nuiton.i18n.I18n.n_;
import com.jurismarches.vradi.ui.OfferEditHandler;
import org.jdesktop.swingx.JXDatePicker;
import jaxx.runtime.DataBindingListener;

public class StringEditor extends com.jurismarches.vradi.ui.editors.VradiEditor {
    private static String $jaxxObjectDescriptor = "H4sIAAAAAAAAAI1SsW4TQRR8PmwHJ5gELKwgghQg9ZreCIIMFkQGJByhCDesvat4rfPdsvsuORrEJ/AJ0NMg0VEhCmoKGsQvIERBi3h7d/HZcAhcnKXdmXmzM+/VV6hYAxcmPI6ZiQJUU8l2ru/t3RtO5AhvSDsySmNoIP2VPPAGsCJm5xbh0qDn6K2M3uqEUx0GMphjt3uwbPGJL+1YSkQ4v8gYWdvqz67bsY7MkerMVJHqi+/fvOfi2UsPINbkrkxP2fwXK39JuQeeEginadIBb/k82CcbRgX75Lfuzjo+t/Yun8rH8BSWelDV3JAYwsX/f3KikfBjjVDfemC4UDeFIsxlBDYKp2wSGWWn3IzG0rIDd88ixWSCsSy1lDK0TqSqCGXBkSOsOZvMWc9wOaKeCnTCABPP6wvJ2EMCs10+9GVOqaYUhKaTjTPQzq6MsaukLxxsVVPK5xa0qD+W95cHXBpAxUR0TMMHf1Z+n67Sstd/K9sJJrc/m41Pb7+86R41XKLZZwqhcwtKyWsTamlQudGrab0RKr91h+v2AGpW+rTdyfZuFBjrZ9dkjuadSiJ2dHaL2zFJVJY+v3vffPTxGHhdWPZDLrrc4W9DDceGUgh9Eetr24mjE4fH6bvmvFFrSFEinLzi2tscqkBQwFdjimCjIIKZj2Htw49G//X2fAxn/wrPo6g8hKoKfBXIZNWzLS5c7RVtZSTCfFuL9rfk/hta61/Suj+mOAQAAA==";
    private static final long serialVersionUID = 1L;
    protected java.lang.String data;
    protected javax.swing.JTextField editor;
    private StringEditor $VradiEditor0 = this;
    private boolean allComponentsCreated;
    private boolean contextInitialized = true;
    private PropertyChangeListener $DataSource1 = new DataBindingListener(this, "editor.text");

    /* begin raw body code */    
    
    protected OfferEditHandler getHandler() {
        return getContextValue(OfferEditHandler.class);
    }
    
    protected VradiContext getVradiContext() {
        return VradiContext.get();
    }
    
    void $afterCompleteSetup() {
    }
    /* end raw body code */
    /*---------------------------------------------------------------------------------*/
    /*-- Statics methods --------------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public static jaxx.runtime.JAXXObjectDescriptor $getJAXXObjectDescriptor() {
        return jaxx.runtime.Util.decodeCompressedJAXXObjectDescriptor($jaxxObjectDescriptor);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- Constructors -----------------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public StringEditor() {
        super();
        $initialize();
    }

    public StringEditor(jaxx.runtime.JAXXContext parentContext) {
        super(parentContext);
        $initialize();
    }

    /*---------------------------------------------------------------------------------*/
    /*-- JAXXObject implementation ----------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    @Override
    public void applyDataBinding(String $binding) {
        if ("editor.text".equals($binding)) {    
            addPropertyChangeListener("data", $DataSource1);
        } else {
            super.applyDataBinding($binding);
            return;
        }
        processDataBinding($binding);
    }

    @Override
    public void processDataBinding(String $dest, boolean $force) {
        if (!$force && $activeBindings.contains($dest)) { 
            return;
        }
        $activeBindings.add($dest);
        try {
            if ("editor.text".equals($dest)) {
                jaxx.runtime.SwingUtil.setText(editor, getData());
            } else {
                super.processDataBinding($dest, true);
            }
        } finally {
            $activeBindings.remove($dest);
        }
    }

    @Override
    public void removeDataBinding(String $binding) {
        if ("editor.text".equals($binding)) {    
            removePropertyChangeListener("data", $DataSource1);
        } else {
            super.removeDataBinding($binding);
        }
    }

    /*---------------------------------------------------------------------------------*/
    /*-- public acessor methods -------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public java.lang.String getData() {
        return data;
    }

    public javax.swing.JTextField getEditor() {
        return editor;
    }

    /*---------------------------------------------------------------------------------*/
    /*-- public mutator methods -------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public void setData(java.lang.String newValue) {
        java.lang.String oldValue = this.data;
        this.data = newValue;
        firePropertyChange("data", oldValue, newValue);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- ui creation methods ----------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    private void $completeSetup() {
        allComponentsCreated = true;
        addChildrenToEditorContent();
        // init data bindings
        applyDataBinding("editor.text");
        $afterCompleteSetup();
    }

    private void $initialize() {
        if (allComponentsCreated || !contextInitialized) {
            return;
        }
        $objectMap.put("$VradiEditor0", this);
        createData();
        createEditor();
        // inline creation of $VradiEditor0
        removeDataBinding("$Table0.name");
        setName("$VradiEditor0");
        
        $completeSetup();
    }

    protected void addChildrenToEditorContent() {
        if (!allComponentsCreated) {
            return;
        }
        editorContent.add(editor, new GridBagConstraints(0, 0, 1, 1, 1.0, 0.0, 10, 2, new Insets(0, 0, 0, 0), 0, 0));
    }

    protected void createData() {
        $objectMap.put("data", data = null);
    }

    protected void createEditor() {
        $objectMap.put("editor", editor = new javax.swing.JTextField());
        editor.setName("editor");
        editor.setColumns(15);
    }

    @Override
    protected void createEditorContent() {
        $objectMap.put("editorContent", editorContent = new jaxx.runtime.swing.Table());
        editorContent.setName("editorContent");
    }

}
